==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/inputs/SpeechEndpointDeploymentResourcePropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.inputs

import com.pulumi.azurenative.machinelearningservices.inputs.SpeechEndpointDeploymentResourcePropertiesArgs.builder
import com.pulumi.azurenative.machinelearningservices.kotlin.enums.DeploymentModelVersionUpgradeOption
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property failureReason The failure reason if the creation failed.
 * @property model Model used for the endpoint deployment.
 * @property raiPolicyName The name of RAI policy.
 * @property sku
 * @property type Kind of the deployment.
 * Expected value is 'Azure.Speech'.
 * @property versionUpgradeOption Deployment model version upgrade option.
 */
public data class SpeechEndpointDeploymentResourcePropertiesArgs(
    public val failureReason: Output<String>? = null,
    public val model: Output<EndpointDeploymentModelArgs>,
    public val raiPolicyName: Output<String>? = null,
    public val sku: Output<CognitiveServicesSkuArgs>? = null,
    public val type: Output<String>,
    public val versionUpgradeOption: Output<Either<String, DeploymentModelVersionUpgradeOption>>? =
        null,
) :
    ConvertibleToJava<com.pulumi.azurenative.machinelearningservices.inputs.SpeechEndpointDeploymentResourcePropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.machinelearningservices.inputs.SpeechEndpointDeploymentResourcePropertiesArgs =
        com.pulumi.azurenative.machinelearningservices.inputs.SpeechEndpointDeploymentResourcePropertiesArgs.builder()
            .failureReason(failureReason?.applyValue({ args0 -> args0 }))
            .model(model.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .raiPolicyName(raiPolicyName?.applyValue({ args0 -> args0 }))
            .sku(sku?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .type(type.applyValue({ args0 -> args0 }))
            .versionUpgradeOption(
                versionUpgradeOption?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            ).build()
}

/**
 * Builder for [SpeechEndpointDeploymentResourcePropertiesArgs].
 */
@PulumiTagMarker
public class SpeechEndpointDeploymentResourcePropertiesArgsBuilder internal constructor() {
    private var failureReason: Output<String>? = null

    private var model: Output<EndpointDeploymentModelArgs>? = null

    private var raiPolicyName: Output<String>? = null

    private var sku: Output<CognitiveServicesSkuArgs>? = null

    private var type: Output<String>? = null

    private var versionUpgradeOption: Output<Either<String, DeploymentModelVersionUpgradeOption>>? =
        null

    /**
     * @param value The failure reason if the creation failed.
     */
    @JvmName("gwtamajuqrjwqbms")
    public suspend fun failureReason(`value`: Output<String>) {
        this.failureReason = value
    }

    /**
     * @param value Model used for the endpoint deployment.
     */
    @JvmName("wrkreknkgohbsswp")
    public suspend fun model(`value`: Output<EndpointDeploymentModelArgs>) {
        this.model = value
    }

    /**
     * @param value The name of RAI policy.
     */
    @JvmName("yubffrriwbnsosms")
    public suspend fun raiPolicyName(`value`: Output<String>) {
        this.raiPolicyName = value
    }

    /**
     * @param value
     */
    @JvmName("hvxksgxahkgmsyqc")
    public suspend fun sku(`value`: Output<CognitiveServicesSkuArgs>) {
        this.sku = value
    }

    /**
     * @param value Kind of the deployment.
     * Expected value is 'Azure.Speech'.
     */
    @JvmName("kkwcyufoyqwonuuv")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value Deployment model version upgrade option.
     */
    @JvmName("srehedopxhfjauvl")
    public suspend
    fun versionUpgradeOption(`value`: Output<Either<String, DeploymentModelVersionUpgradeOption>>) {
        this.versionUpgradeOption = value
    }

    /**
     * @param value The failure reason if the creation failed.
     */
    @JvmName("gvxlheciijkqlodh")
    public suspend fun failureReason(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.failureReason = mapped
    }

    /**
     * @param value Model used for the endpoint deployment.
     */
    @JvmName("rjnprkftycuvxrvb")
    public suspend fun model(`value`: EndpointDeploymentModelArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.model = mapped
    }

    /**
     * @param argument Model used for the endpoint deployment.
     */
    @JvmName("gicrpgvsvcniiubc")
    public suspend fun model(argument: suspend EndpointDeploymentModelArgsBuilder.() -> Unit) {
        val toBeMapped = EndpointDeploymentModelArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.model = mapped
    }

    /**
     * @param value The name of RAI policy.
     */
    @JvmName("vgkpgadbpxqpebbh")
    public suspend fun raiPolicyName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.raiPolicyName = mapped
    }

    /**
     * @param value
     */
    @JvmName("tjxuguclaiehwswh")
    public suspend fun sku(`value`: CognitiveServicesSkuArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sku = mapped
    }

    /**
     * @param argument
     */
    @JvmName("wrsmjhaohdomlrwm")
    public suspend fun sku(argument: suspend CognitiveServicesSkuArgsBuilder.() -> Unit) {
        val toBeMapped = CognitiveServicesSkuArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.sku = mapped
    }

    /**
     * @param value Kind of the deployment.
     * Expected value is 'Azure.Speech'.
     */
    @JvmName("sqkomuecbflsqqnl")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value Deployment model version upgrade option.
     */
    @JvmName("fqnraoiwjtewcave")
    public suspend
    fun versionUpgradeOption(`value`: Either<String, DeploymentModelVersionUpgradeOption>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.versionUpgradeOption = mapped
    }

    /**
     * @param value Deployment model version upgrade option.
     */
    @JvmName("nomxapedsiokklly")
    public fun versionUpgradeOption(`value`: String) {
        val toBeMapped = Either.ofLeft<String, DeploymentModelVersionUpgradeOption>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.versionUpgradeOption = mapped
    }

    /**
     * @param value Deployment model version upgrade option.
     */
    @JvmName("pipjqndeixfjybgf")
    public fun versionUpgradeOption(`value`: DeploymentModelVersionUpgradeOption) {
        val toBeMapped = Either.ofRight<String, DeploymentModelVersionUpgradeOption>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.versionUpgradeOption = mapped
    }

    internal fun build(): SpeechEndpointDeploymentResourcePropertiesArgs =
        SpeechEndpointDeploymentResourcePropertiesArgs(
            failureReason = failureReason,
            model = model ?: throw PulumiNullFieldException("model"),
            raiPolicyName = raiPolicyName,
            sku = sku,
            type = type ?: throw PulumiNullFieldException("type"),
            versionUpgradeOption = versionUpgradeOption,
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/inputs/SpeechEndpointDeploymentResourcePropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.inputs

import com.pulumi.azurenative.machinelearningservices.inputs.SpeechEndpointDeploymentResourcePropertiesArgs.builder
import com.pulumi.azurenative.machinelearningservices.kotlin.enums.DeploymentModelVersionUpgradeOption
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property failureReason The failure reason if the creation failed.
 * @property model Model used for the endpoint deployment.
 * @property raiPolicyName The name of RAI policy.
 * @property sku
 * @property type Kind of the deployment.
 * Expected value is 'Azure.Speech'.
 * @property versionUpgradeOption Deployment model version upgrade option.
 */
public data class SpeechEndpointDeploymentResourcePropertiesArgs(
    public val failureReason: Output<String>? = null,
    public val model: Output<EndpointDeploymentModelArgs>,
    public val raiPolicyName: Output<String>? = null,
    public val sku: Output<CognitiveServicesSkuArgs>? = null,
    public val type: Output<String>,
    public val versionUpgradeOption: Output<Either<String, DeploymentModelVersionUpgradeOption>>? =
        null,
) :
    ConvertibleToJava<com.pulumi.azurenative.machinelearningservices.inputs.SpeechEndpointDeploymentResourcePropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.machinelearningservices.inputs.SpeechEndpointDeploymentResourcePropertiesArgs =
        com.pulumi.azurenative.machinelearningservices.inputs.SpeechEndpointDeploymentResourcePropertiesArgs.builder()
            .failureReason(failureReason?.applyValue({ args0 -> args0 }))
            .model(model.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .raiPolicyName(raiPolicyName?.applyValue({ args0 -> args0 }))
            .sku(sku?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .type(type.applyValue({ args0 -> args0 }))
            .versionUpgradeOption(
                versionUpgradeOption?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            ).build()
}

/**
 * Builder for [SpeechEndpointDeploymentResourcePropertiesArgs].
 */
@PulumiTagMarker
public class SpeechEndpointDeploymentResourcePropertiesArgsBuilder internal constructor() {
    private var failureReason: Output<String>? = null

    private var model: Output<EndpointDeploymentModelArgs>? = null

    private var raiPolicyName: Output<String>? = null

    private var sku: Output<CognitiveServicesSkuArgs>? = null

    private var type: Output<String>? = null

    private var versionUpgradeOption: Output<Either<String, DeploymentModelVersionUpgradeOption>>? =
        null

    /**
     * @param value The failure reason if the creation failed.
     */
    @JvmName("fuaabemsxsmwxqhy")
    public suspend fun failureReason(`value`: Output<String>) {
        this.failureReason = value
    }

    /**
     * @param value Model used for the endpoint deployment.
     */
    @JvmName("uglxydbdcoijpwya")
    public suspend fun model(`value`: Output<EndpointDeploymentModelArgs>) {
        this.model = value
    }

    /**
     * @param value The name of RAI policy.
     */
    @JvmName("dcsdiraxjsxmgmlr")
    public suspend fun raiPolicyName(`value`: Output<String>) {
        this.raiPolicyName = value
    }

    /**
     * @param value
     */
    @JvmName("ygyewaarlbmikfdt")
    public suspend fun sku(`value`: Output<CognitiveServicesSkuArgs>) {
        this.sku = value
    }

    /**
     * @param value Kind of the deployment.
     * Expected value is 'Azure.Speech'.
     */
    @JvmName("cuqyhqddcgkhgnmu")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value Deployment model version upgrade option.
     */
    @JvmName("yuvfdjgnidhruhic")
    public suspend
    fun versionUpgradeOption(`value`: Output<Either<String, DeploymentModelVersionUpgradeOption>>) {
        this.versionUpgradeOption = value
    }

    /**
     * @param value The failure reason if the creation failed.
     */
    @JvmName("cnsqpuagxpsnmjlf")
    public suspend fun failureReason(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.failureReason = mapped
    }

    /**
     * @param value Model used for the endpoint deployment.
     */
    @JvmName("immuicecuvajdwik")
    public suspend fun model(`value`: EndpointDeploymentModelArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.model = mapped
    }

    /**
     * @param argument Model used for the endpoint deployment.
     */
    @JvmName("iopomuuttywujebn")
    public suspend fun model(argument: suspend EndpointDeploymentModelArgsBuilder.() -> Unit) {
        val toBeMapped = EndpointDeploymentModelArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.model = mapped
    }

    /**
     * @param value The name of RAI policy.
     */
    @JvmName("yjejfjdpubwljeff")
    public suspend fun raiPolicyName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.raiPolicyName = mapped
    }

    /**
     * @param value
     */
    @JvmName("vyplorauyrkqmyyr")
    public suspend fun sku(`value`: CognitiveServicesSkuArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sku = mapped
    }

    /**
     * @param argument
     */
    @JvmName("lduttyidrlsrrlgd")
    public suspend fun sku(argument: suspend CognitiveServicesSkuArgsBuilder.() -> Unit) {
        val toBeMapped = CognitiveServicesSkuArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.sku = mapped
    }

    /**
     * @param value Kind of the deployment.
     * Expected value is 'Azure.Speech'.
     */
    @JvmName("jnpptwridmoxibpa")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value Deployment model version upgrade option.
     */
    @JvmName("tublqtciycdpxpos")
    public suspend
    fun versionUpgradeOption(`value`: Either<String, DeploymentModelVersionUpgradeOption>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.versionUpgradeOption = mapped
    }

    /**
     * @param value Deployment model version upgrade option.
     */
    @JvmName("gqygxacoxoljhpoa")
    public fun versionUpgradeOption(`value`: String) {
        val toBeMapped = Either.ofLeft<String, DeploymentModelVersionUpgradeOption>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.versionUpgradeOption = mapped
    }

    /**
     * @param value Deployment model version upgrade option.
     */
    @JvmName("qmjciylqsuwshctc")
    public fun versionUpgradeOption(`value`: DeploymentModelVersionUpgradeOption) {
        val toBeMapped = Either.ofRight<String, DeploymentModelVersionUpgradeOption>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.versionUpgradeOption = mapped
    }

    internal fun build(): SpeechEndpointDeploymentResourcePropertiesArgs =
        SpeechEndpointDeploymentResourcePropertiesArgs(
            failureReason = failureReason,
            model = model ?: throw PulumiNullFieldException("model"),
            raiPolicyName = raiPolicyName,
            sku = sku,
            type = type ?: throw PulumiNullFieldException("type"),
            versionUpgradeOption = versionUpgradeOption,
        )
}
